====================
The ``lino`` package
====================





.. raw:: html

    <a class="reference external" 
    href="http://lino.readthedocs.io/en/latest/?badge=latest"><img
    alt="Documentation Status"
    src="https://readthedocs.org/projects/lino/badge/?version=latest"
    /></a> <a class="reference external"
    href="https://coveralls.io/github/lino-framework/book?branch=master"><img
    alt="coverage"
    src="https://coveralls.io/repos/github/lino-framework/book/badge.svg?branch=master"
    /></a> <a class="reference external"
    href="https://travis-ci.org/lino-framework/book?branch=stable"><img
    alt="build"
    src="https://travis-ci.org/lino-framework/book.svg?branch=stable"
    /></a> <a class="reference external"
    href="https://pypi.python.org/pypi/lino/"><img alt="pypi_v"
    src="https://img.shields.io/pypi/v/lino.svg" /></a> <a
    class="reference external"
    href="https://pypi.python.org/pypi/lino/"><img alt="pypi_license"
    src="https://img.shields.io/pypi/l/lino.svg" /></a>

Lino is a high-level framework for writing desktop-like customized database
applications based on `Django <https://www.djangoproject.com/>`_ and `Sencha
ExtJS <http://www.sencha.com/products/extjs/>`_. Lino applications are Django
projects where the application developer does not need to write any URLconf,
HTML nor CSS (`more <http://lino-framework.org/about/what.html>`__).

- This repository is considered an integral part of the Lino framework, which is
  documented as a whole in the `Lino Book
  <http://www.lino-framework.org/dev/overview.html>`__.
 
- Your feedback is welcome.  Our `community page
  <http://www.lino-framework.org/community>`__ explains how to contact us.
  
- Changes to this particular repository are listed at
  http://core.lino-framework.org/changes/


